@@ -9,7 +9,25 @@ import zope.interface
 
 
 class IntegrityError(Exception):
-    pass
+
+    def __init__(self, to_delete, referenced):
+        self.to_delete = to_delete
+        self.referenced = referenced
+
+    def __str__(self):
+        return ("Can't delete or move %r. The (sub-)object %r is still being "
+                "referenced." % (self.to_delete, self.referenced))
+
+
+class LookupError(KeyError):
+
+    def __init__(self, target_key, reference):
+        self.target_key = target_key
+        self.reference = reference
+
+    def __str__(self):
+        return "Target %r of reference %r no longer exists." % (
+            self.target_key, self.reference.__name__)
 
 
 class IReferenceSource(zope.interface.Interface):
